Rename the arguments of tcg2_get_pcr_info() to clarify
they are bank masks, not PCR mask.
Remove the unused local variable.

Signed-off-by: Raymond Mao <raymond....@linaro.org>
Reviewed-by: Ilias Apalodimas <ilias.apalodi...@linaro.org>
---
Changes in v2
- Rebased to 'next'.

 include/tpm_tcg2.h | 12 ++++++------
 lib/tpm_tcg2.c     | 19 ++++++++-----------
 2 files changed, 14 insertions(+), 17 deletions(-)

diff --git a/lib/tpm_tcg2.c b/lib/tpm_tcg2.c
index edbe5f3aaf..0e267ff0a7 100644
--- a/lib/tpm_tcg2.c
+++ b/lib/tpm_tcg2.c
@@ -20,19 +20,16 @@
 #include <linux/unaligned/le_byteshift.h>
 #include "tpm-utils.h"
 
-int tcg2_get_pcr_info(struct udevice *dev, u32 *supported_pcr, u32 *active_pcr,
-                     u32 *pcr_banks)
+int tcg2_get_pcr_info(struct udevice *dev, u32 *supported_bank, u32 
*active_bank,
+                     u32 *bank_num)
 {
-       u8 response[(sizeof(struct tpms_capability_data) -
-               offsetof(struct tpms_capability_data, data))];
        struct tpml_pcr_selection pcrs;
        size_t i;
        u32 ret;
 
-       *supported_pcr = 0;
-       *active_pcr = 0;
-       *pcr_banks = 0;
-       memset(response, 0, sizeof(response));
+       *supported_bank = 0;
+       *active_bank = 0;
+       *bank_num = 0;
 
        ret = tpm2_get_pcr_info(dev, &pcrs);
        if (ret)
@@ -42,16 +39,16 @@ int tcg2_get_pcr_info(struct udevice *dev, u32 
*supported_pcr, u32 *active_pcr,
                u32 hash_mask = tcg2_algorithm_to_mask(pcrs.selection[i].hash);
 
                if (hash_mask) {
-                       *supported_pcr |= hash_mask;
+                       *supported_bank |= hash_mask;
                        if (tpm2_is_active_bank(&pcrs.selection[i]))
-                               *active_pcr |= hash_mask;
+                               *active_bank |= hash_mask;
                } else {
                        printf("%s: unknown algorithm %x\n", __func__,
                               pcrs.selection[i].hash);
                }
        }
 
-       *pcr_banks = pcrs.count;
+       *bank_num = pcrs.count;
 
        return 0;
 }
diff --git a/include/tpm_tcg2.h b/include/tpm_tcg2.h
index 6519004cc4..eb6afe49e7 100644
--- a/include/tpm_tcg2.h
+++ b/include/tpm_tcg2.h
@@ -94,17 +94,17 @@ struct tcg_pcr_event {
 } __packed;
 
 /**
- * tcg2_get_pcr_info() - get the supported, active PCRs and number of banks
+ * tcg2_get_pcr_info() - get the supported, active banks and number of banks
  *
  * @dev:               TPM device
  * @supported_pcr:     bitmask with the algorithms supported
  * @active_pcr:                bitmask with the active algorithms
  * @pcr_banks:         number of PCR banks
  *
  * @return 0 on success, code of operation or negative errno on failure
  */
-int tcg2_get_pcr_info(struct udevice *dev, u32 *supported_pcr, u32 *active_pcr,
-                     u32 *pcr_banks);
+int tcg2_get_pcr_info(struct udevice *dev, u32 *supported_bank, u32 
*active_bank,
+                     u32 *bank_num);
 
 /**
  * Crypto Agile Log Entry Format
@@ -94,17 +94,17 @@ struct tcg_pcr_event {
  *
  * @dev:               TPM device
- * @supported_pcr:     bitmask with the algorithms supported
- * @active_pcr:                bitmask with the active algorithms
- * @pcr_banks:         number of PCR banks
+ * @supported_bank:    bitmask with the algorithms supported
+ * @active_bank:       bitmask with the active algorithms
+ * @bank_num:          number of PCR banks
  *
  * @return 0 on success, code of operation or negative errno on failure
-- 
2.25.1

Reply via email to